@@ -133,9 +133,6 @@ static NS_DEFINE_CID(kHttpAuthManagerCID,        NS_HTTPAUTHMANAGER_CID);
   }                                                           \
   PR_END_MACRO
 
-// CID used to get the plugin manager
-static NS_DEFINE_CID(kPluginManagerCID, NS_PLUGINMANAGER_CID);
-
 // class and instance initialization
 
 static void
@@ -677,18 +674,11 @@ static PRBool
 gtk_moz_embed_common_get_npplugin_list(PRUint32 *aLength, GList **pluginArray)
 {
   nsresult rv;
-  nsCOMPtr<nsIPluginManager> pluginMan =
-    do_GetService(kPluginManagerCID, &rv);
-  if (NS_FAILED(rv)) {
-    NS_WARNING("Could not get the plugin manager\n");
-    return FALSE;
-  }
-  pluginMan->ReloadPlugins(PR_FALSE);  //FIXME XXX MEMLEAK
-
-  nsCOMPtr<nsIPluginHost> pluginHost =
-    do_GetService(kPluginManagerCID, &rv);
+  nsCOMPtr<nsIPluginHost> pluginHost(do_GetService(MOZ_PLUGIN_HOST_CONTRACTID, &rv));
   NS_ENSURE_SUCCESS(rv, FALSE);
 
+  pluginHost->ReloadPlugins(PR_FALSE);  //FIXME XXX MEMLEAK
+
   pluginHost->GetPluginCount(aLength);
 
   if (!pluginArray)
@@ -785,9 +775,8 @@ void
 gtk_moz_embed_common_reload_plugins(gboolean full_reload)
 {
   nsresult rv;
-  nsCOMPtr<nsIPluginManager> pluginMan =
-    do_GetService(kPluginManagerCID, &rv);
-  pluginMan->ReloadPlugins(PR_TRUE); //FIXME XXX MEMLEAK
+  nsCOMPtr<nsIPluginHost> pluginHost(do_GetService(MOZ_PLUGIN_HOST_CONTRACTID, &rv));
+  pluginHost->ReloadPlugins(PR_TRUE); //FIXME XXX MEMLEAK
   if (full_reload)
     g_idle_add(idle_reload, nsnull);
 }
